
//////////////////////////////////////////////////////////////
//
// Source file for MainWindowMainWindow
//
//    This class is a subclass of VkWindow
//
//
// Normally, very little in this file should need to be changed.
// Create/add/modify menus using RapidApp.
//
// Try to restrict any changes to the bodies of functions
// corresponding to menu items, the constructor and destructor.
//
// Restrict changes to those sections between
// the "//--- Start/End editable code block" markers
//
// Doing so will allow you to make changes using RapidApp
// without losing any changes you may have made manually
//
// Avoid gratuitous reformatting and other changes that might
// make it difficult to integrate changes made using RapidApp
//////////////////////////////////////////////////////////////
#include "MainWindowMainWindow.h"

#include <Vk/VkApp.h>
#include <Vk/VkFileSelectionDialog.h>
#include <Vk/VkSubMenu.h>
#include <Vk/VkRadioSubMenu.h>
#include <Vk/VkMenuItem.h>
#include <Vk/VkMenuBar.h>
#include <Vk/VkResource.h>


// Externally defined classes referenced by this class: 

#include "Form.h"

extern void VkUnimplemented ( Widget, const char * );

//---- Start editable code block: headers and declarations


//---- End editable code block: headers and declarations



// These are default resources for widgets in objects of this class
// All resources will be prepended by *<name> at instantiation,
// where <name> is the name of the specific instance, as well as the
// name of the baseWidget. These are only defaults, and may be overriden
// in a resource file by providing a more specific resource name

String  MainWindowMainWindow::_defaultMainWindowMainWindowResources[] = {
        "*exitButton.accelerator:  Ctrl<Key>Q",
        "*exitButton.acceleratorText:  Ctrl+Q",
        "*exitButton.labelString:  Exit",
        "*exitButton.mnemonic:  x",
        "*filePane.labelString:  File",
        "*filePane.mnemonic:  F",
        "*helpPane.labelString:  Help",
        "*helpPane.mnemonic:  H",
	/*
	"*help_click_for_help.accelerator:  Shift<Key>F1",
        "*help_click_for_help.acceleratorText:  Shift+F1",
        "*help_click_for_help.labelString:  Click For Help",
        "*help_click_for_help.mnemonic:  C",
        "*help_index.labelString:  Index",
        "*help_index.mnemonic:  I",
        "*help_keys_and_short.labelString:  Keys and Shortcuts",
        "*help_keys_and_short.mnemonic:  K",
	*/
        "*help_overview.labelString:  Overview",
        "*help_overview.mnemonic:  O",
	/*
        "*help_prod_info.labelString:  Product Information",
        "*help_prod_info.mnemonic:  P",
	*/
        "*title:  BuenaVista Audio Tool",

        //---- Start editable code block: MainWindowMainWindow Default Resources


        //---- End editable code block: MainWindowMainWindow Default Resources

        (char*)NULL
};


//---- Class declaration

MainWindowMainWindow::MainWindowMainWindow ( const char *name,
                                            ArgList args,
                                            Cardinal argCount) : 
                                      VkWindow ( name, args, argCount )
{
    // Load any class-default resources for this object

    setDefaultResources ( baseWidget(), _defaultMainWindowMainWindowResources  );


    // Create the view component contained by this window

    _form = new Form ( "form",mainWindowWidget() );


    XtVaSetValues ( _form->baseWidget(),
                    XmNwidth, 240, 
                    XmNheight, 359, 
                    (XtPointer) NULL );

    // Add the component as the main view

    addView ( _form );

    // Set up the window manager properties for this window.
    // This window cannot be resized by the user.

     VkConfigureWM ( this,
                    TRUE,  //quit
                    TRUE,  // close
                    TRUE,   // border
                    TRUE,   // title
                    FALSE,  // allow resize
                    TRUE,   // allow iconify
                    TRUE);  // Show window manager menu

    // Create the panes of this window's menubar. The menubar itself
    // is created automatically by ViewKit


    // The filePane menu pane

    _filePane =  addMenuPane ( "filePane" );

    _separator1 =  _filePane->addSeparator();

    _exitButton =  _filePane->addAction ( "exitButton", 
                                        &MainWindowMainWindow::quitCallback, 
                                        (XtPointer) this );


    //---- Start editable code block: MainWindowMainWindow constructor


    //---- End editable code block: MainWindowMainWindow constructor


}    // End Constructor


MainWindowMainWindow::~MainWindowMainWindow()
{
    delete _form;
    //---- Start editable code block: MainWindowMainWindow destructor


    //---- End editable code block: MainWindowMainWindow destructor
}    // End destructor


const char *MainWindowMainWindow::className()
{
    return ("MainWindowMainWindow");
}    // End className()


Boolean MainWindowMainWindow::okToQuit()
{
    //---- Start editable code block: MainWindowMainWindow okToQuit



    // This member function is called when the user quits by calling
    // theApplication->terminate() or uses the window manager close protocol
    // This function can abort the operation by returning FALSE, or do some.
    // cleanup before returning TRUE. The actual decision is normally passed on
    // to the view object


    // Query the view object, and give it a chance to cleanup

    return ( _form->okToQuit() );

    //---- End editable code block: MainWindowMainWindow okToQuit
}    // End okToQuit()

void MainWindowMainWindow::afterRealizeHook()
{
    // Retrieve the help menu pane and remove it

    menu()->showHelpPane(FALSE);
}


/////////////////////////////////////////////////////////////// 
// The following functions are static member functions used to 
// interface with Motif.
/////////////////////////////////// 

void MainWindowMainWindow::quitCallback ( Widget    w,
                                          XtPointer clientData,
                                          XtPointer callData ) 
{ 
    MainWindowMainWindow* obj = ( MainWindowMainWindow * ) clientData;
    obj->quit ( w, callData );
}





/////////////////////////////////////////////////////////////// 
// The following functions are called from callbacks 
/////////////////////////////////// 

void MainWindowMainWindow::quit ( Widget, XtPointer ) 
{
    // Exit via quitYourself() to allow the application
    // to go through its normal shutdown routines, checking with
    // all windows, views, and so on.

    theApplication->quitYourself();

}    // End MainWindowMainWindow::quit()




//---- Start editable code block: End of generated code


//---- End editable code block: End of generated code


